========
inliners
========

Overview
--------

Parse a string representing multiple strings.

Installation
------------

To install ``inliners``, you can use ``pip``. Open your terminal and run:

.. code-block:: bash

    pip install inliners

License
-------

This project is licensed under the MIT License.

Links
-----

* `Documentation <https://pypi.org/project/inliners>`_
* `Download <https://pypi.org/project/inliners/#files>`_
* `Source <https://github.com/johannes-programming/inliners>`_

Credits
-------

* Author: Johannes
* Email: johannes-programming@mailfence.com

Thank you for using ``inliners``!